''' Cytoplasm is a static site compiler meant to be used mostly as a blogging
engine.

See http://cytoplasm.somethingsido.com.
'''

from cytoplasm.site import Site
